==> worldguard-core-7.0.0-20190329.030842-58-sources.jar: com/sk89q/worldguard/protection/flags/DoubleFlag.java <==
/*
 * WorldGuard, a suite of tools for Minecraft
 * Copyright (C) sk89q <http://www.sk89q.com>
 * Copyright (C) WorldGuard team and contributors
 *
 * This program is free software: you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published by the
 * Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

package com.sk89q.worldguard.protection.flags;

/**
 * Stores doubles.
 */
public class DoubleFlag extends Flag<Double> {

    public DoubleFlag(String name, RegionGroup defaultGroup) {
        super(name, defaultGroup);
    }

    public DoubleFlag(String name) {
        super(name);
    }

    @Override
    public Double parseInput(FlagContext context) throws InvalidFlagFormat {
        return context.getUserInputAsDouble();
    }

    @Override
    public Double unmarshal(Object o) {
        if (o instanceof Double) {
            return (Double) o;
        } else if (o instanceof Number) {
            return ((Number) o).doubleValue();
        } else {
            return null;
        }
    }

    @Override
    public Object marshal(Double o) {
        return o;
    }
}

==> worldguard-core-7.0.6-20210724.153920-4-sources.jar: com/sk89q/worldguard/protection/flags/DoubleFlag.java <==
/*
 * WorldGuard, a suite of tools for Minecraft
 * Copyright (C) sk89q <http://www.sk89q.com>
 * Copyright (C) WorldGuard team and contributors
 *
 * This program is free software: you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published by the
 * Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

package com.sk89q.worldguard.protection.flags;

/**
 * Stores doubles.
 */
public class DoubleFlag extends NumberFlag<Double> {

    public DoubleFlag(String name, RegionGroup defaultGroup) {
        super(name, defaultGroup);
    }

    public DoubleFlag(String name) {
        super(name);
    }

    @Override
    public Double parseInput(FlagContext context) throws InvalidFlagFormat {
        return context.getUserInputAsDouble();
    }

    @Override
    public Double unmarshal(Object o) {
        if (o instanceof Double) {
            return (Double) o;
        } else if (o instanceof Number) {
            return ((Number) o).doubleValue();
        } else {
            return null;
        }
    }

    @Override
    public Object marshal(Double o) {
        return o;
    }
}
